@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 
 from PyQt4 import QtCore, QtGui
-import time, os
+import os
+import time
 import zipfile
 
 class Ui_MainWindow(object):
@@ -191,9 +192,8 @@ class Ui_MainWindow(object):
 
     def savePage(self):
         s=str(self.page)
-        os.chmod(0666, "/usr/lib/quran/quran_track.ptr")
-
-	f = open('/usr/lib/quran/quran_track.ptr', "w")
+        os.chmod("/opt/quran/quran_track.ptr",0666)
+	f = open('/opt/quran/quran_track.ptr', "w")
         f.write(s)
         f.close()
         QtGui.QMessageBox.information(None, 'Save','This page is already saved', QtGui.QMessageBox.Close)
@@ -201,7 +201,7 @@ class Ui_MainWindow(object):
 
 
     def loadPage(self):
-        f = QtCore.QFile('/usr/lib/quran/quran_track.ptr')
+        f = QtCore.QFile('/opt/quran/quran_track.ptr')
         f.open(QtCore.QIODevice.ReadOnly)
         strpage=QtCore.QTextStream(f).readLine()
         self.page=int(strpage)
